@@ -50,7 +50,7 @@ if(metric=="Aitchison" & primitive==FALSE){
 findknn <- function(x, i, j){
   m1 <- which(!is.na(x[i,]))
   mi <- which(c(!is.na(x[,j,drop=FALSE])) & c(!is.na(rowSums(x[,m1,drop=FALSE]))))
-  xclr <- clr(rbind(x[mi, m1, drop=FALSE], x[i, m1]))
+  xclr <- clr(rbind(x[mi, m1, drop=FALSE], x[i, m1]))$x.clr
   d <- rowSums(t(abs(t(xclr[-nrow(xclr),]) - c(xclr[nrow(xclr),]))))
   names(d) <- mi
   wA <- which(d <= quantile(d, k/length(d)))
@@ -111,7 +111,7 @@ findknn <- function(x, i, j){
   a <- c(!is.na(x[,j,drop=FALSE]))
   b <- ifelse(rowSums(is.na(x[,-j])) == 0, TRUE, FALSE)
   mi <- which(a & b)
-  xclr <- clr(rbind(x[mi, m1, drop=FALSE], x[i, m1]))
+  xclr <- clr(rbind(x[mi, m1, drop=FALSE], x[i, m1]))$x.clr
   d <- rowSums(t(abs(t(xclr[-nrow(xclr),]) - c(xclr[nrow(xclr),]))), na.rm=TRUE)
   #d[d == 0] <- NA   ## dirty
   names(d) <- mi
